<?php
/**
 * Functions which enhance the theme by hooking into WordPress
 *
 * @package Moral
 */

/**
 * Adds custom classes to the array of body classes.
 *
 * @param array $classes Classes for the body element.
 * @return array
 */
function blogbook_body_classes( $classes ) {
	// Adds a class of hfeed to non-singular pages.
	if ( ! is_singular() ) {
		$classes[] = 'hfeed';
	}

	// When menu is sticky.
	$menu_sticky = get_theme_mod( 'blogbook_make_menu_sticky', false );
	if ( $menu_sticky ) {
		$classes[] = 'menu-sticky';
	}

	// When  color scheme is light or dark.
	$color_scheme = get_theme_mod( 'blogbook_color_scheme', 'lite' );
	$classes[] = $color_scheme . '-version';
	
	// When global archive layout is checked.
	if ( is_archive() || blogbook_is_latest_posts() || is_404() || is_search() ) {
		$archive_sidebar = get_theme_mod( 'blogbook_archive_sidebar', 'both' );
        if( ! is_active_sidebar( 'sidebar-1' ) && ! is_active_sidebar( 'sidebar-2' ) ) {
            $classes[] = 'no-sidebar';
        } elseif ( ! is_active_sidebar( 'sidebar-1' ) ) {
            $classes[] = 'left-sidebar';
        } elseif ( ! is_active_sidebar( 'sidebar-2' ) ) {
            $classes[] = 'right-sidebar';
        } else {
            $classes[] = $archive_sidebar . '-sidebar';
        }
	} elseif ( is_single() ) { // When global post sidebar is checked.
    	$blogbook_post_sidebar_meta = get_post_meta( get_the_ID(), 'blogbook-select-sidebar', true );
        if( ! is_active_sidebar( 'sidebar-1' ) && ! is_active_sidebar( 'sidebar-2' ) ) {
            $classes[] = 'no-sidebar';
        } elseif ( ! is_active_sidebar( 'sidebar-1' ) ) {
            $classes[] = 'left-sidebar';
        } elseif ( ! is_active_sidebar( 'sidebar-2' ) ) {
            $classes[] = 'right-sidebar';
        } elseif ( ! empty( $blogbook_post_sidebar_meta ) ) {
			$classes[] = $blogbook_post_sidebar_meta . '-sidebar';
    	} else {
			$global_post_sidebar = get_theme_mod( 'blogbook_global_post_layout', 'both' ); 
			$classes[] = $global_post_sidebar . '-sidebar';
    	}
	} elseif ( blogbook_is_frontpage_blog() || is_page() ) {
		if ( blogbook_is_frontpage_blog() ) {
			$page_id = get_option( 'page_for_posts' );
		} else {
			$page_id = get_the_ID();
		}

    	$blogbook_page_sidebar_meta = get_post_meta( $page_id, 'blogbook-select-sidebar', true );
        if( ! is_active_sidebar( 'sidebar-1' ) && ! is_active_sidebar( 'sidebar-2' ) ) {
            $classes[] = 'no-sidebar';
        } elseif ( ! is_active_sidebar( 'sidebar-1' ) ) {
            $classes[] = 'left-sidebar';
        } elseif ( ! is_active_sidebar( 'sidebar-2' ) ) {
            $classes[] = 'right-sidebar';
        } elseif ( ! empty( $blogbook_page_sidebar_meta ) ) {
			$classes[] = $blogbook_page_sidebar_meta . '-sidebar';
		} else {
			$global_page_sidebar = get_theme_mod( 'blogbook_global_page_layout', 'both' ); 
			$classes[] = $global_page_sidebar . '-sidebar';
		}
	}

	// Site layout classes
	$site_layout = get_theme_mod( 'blogbook_site_layout', 'wide' );
	$classes[] = esc_attr( $site_layout ) . '-layout';

	return $classes;
}
add_filter( 'body_class', 'blogbook_body_classes' );

function blogbook_post_classes( $classes ) {
	if ( blogbook_is_page_displays_posts() ) {
		// Search 'has-post-thumbnail' returned by default and remove it.
		$key = array_search( 'has-post-thumbnail', $classes );
		unset( $classes[ $key ] );
		
		$archive_img_enable = get_theme_mod( 'blogbook_enable_archive_featured_img', true );

		if( has_post_thumbnail() && $archive_img_enable ) {
			$classes[] = 'has-post-thumbnail';
		} else {
			$classes[] = 'no-post-thumbnail';
		}
	}

	return $classes;
}
add_filter( 'post_class', 'blogbook_post_classes' );

/**
 * Excerpt length
 * 
 * @since Moral 1.0.0
 * @return Excerpt length
 */
function blogbook_excerpt_length( $length ){
	if ( is_admin() ) {
		return $length;
	}

	$length = get_theme_mod( 'blogbook_archive_excerpt_length', 60 );
	return $length;
}
add_filter( 'excerpt_length', 'blogbook_excerpt_length', 999 );

/**
 * Add a pingback url auto-discovery header for singularly identifiable articles.
 */
function blogbook_pingback_header() {
	if ( is_singular() && pings_open() ) {
		echo '<link rel="pingback" href="', esc_url( get_bloginfo( 'pingback_url' ) ), '">';
	}
}
add_action( 'wp_head', 'blogbook_pingback_header' );

/**
 * Get an array of post id and title.
 * 
 */
function blogbook_get_post_choices() {
	$choices = array( '' => esc_html__( '--Select--', 'blogbook-pro' ) );
	$args = array( 'numberposts' => -1, );
	$posts = get_posts( $args );

	foreach ( $posts as $post ) {
		$id = $post->ID;
		$title = $post->post_title;
		$choices[ $id ] = $title;
	}

	return $choices;
}

/**
 * Get an array of cat id and title.
 * 
 */
function blogbook_get_post_cat_choices() {
	$choices = array( '' => esc_html__( '--Select--', 'blogbook-pro' ) );
	$cats = get_categories();

	foreach ( $cats as $cat ) {
		$id = $cat->term_id;
		$title = $cat->name;
		$choices[ $id ] = $title;
	}

	return $choices;
}

/**
 * Checks to see if we're on the homepage or not.
 */
function blogbook_is_frontpage() {
	return ( is_front_page() && ! is_home() );
}

/**
 * Checks to see if Static Front Page is set to "Your latest posts".
 */
function blogbook_is_latest_posts() {
	return ( is_front_page() && is_home() );
}

/**
 * Checks to see if Static Front Page is set to "Posts page".
 */
function blogbook_is_frontpage_blog() {
	return ( is_home() && ! is_front_page() );
}

/**
 * Checks to see if the current page displays any kind of post listing.
 */
function blogbook_is_page_displays_posts() {
	return ( blogbook_is_frontpage_blog() || is_search() || is_archive() || blogbook_is_latest_posts() );
}

/**
 * Pagination in archive/blog/search pages.
 */
function blogbook_posts_pagination() { 
	$archive_pagination = get_theme_mod( 'blogbook_archive_pagination_type', 'numeric' );
	if ( 'disable' === $archive_pagination ) {
		return;
	}
	if ( 'numeric' === $archive_pagination ) {
		the_posts_pagination( array(
            'prev_text'          => blogbook_get_svg( array( 'icon' => 'left-arrow' ) ) . esc_html__( 'Previous', 'blogbook-pro' ),
            'next_text'          => esc_html__( 'Next', 'blogbook-pro' ) . blogbook_get_svg( array( 'icon' => 'left-arrow' ) ),
        ) );
	} elseif ( 'older_newer' === $archive_pagination ) {
        the_posts_navigation( array(
            'prev_text'          => blogbook_get_svg( array( 'icon' => 'left-arrow' ) ) . '<span>'. esc_html__( 'Older', 'blogbook-pro' ) .'</span>',
            'next_text'          => '<span>'. esc_html__( 'Newer', 'blogbook-pro' ) .'</span>' . blogbook_get_svg( array( 'icon' => 'left-arrow' ) ),
        )  );
	}
}

function blogbook_get_svg_by_url( $url = false ) {
	if ( ! $url ) {
		return false;
	}

	$social_icons = blogbook_social_links_icons();

	foreach ( $social_icons as $attr => $value ) {
		if ( false !== strpos( $url, $attr ) ) {
			return blogbook_get_svg( array( 'icon' => esc_attr( $value ) ) );
		}
	}
}

function blogbook_custom_color_scheme() {
    if ( 'custom' != get_theme_mod( 'blogbook_color_scheme' ) ) {
        return;
    }
    $color = get_theme_mod( 'blogbook_custom_color_scheme', '#ff8737' );
    $custom_css = '
           	/*--------------------------------------------------------------
            ## Text Color
            --------------------------------------------------------------*/
            a,
            #secondary .widget-title, 
            #secondary .widgettitle, 
            #left-sidebar .widget-title, 
            #left-sidebar .widgettitle,
            .blog-posts .entry-title a:hover, 
            .blog-posts .entry-title a:focus, 
            .tags-links a:hover, 
            .comments-link a:hover, 
            .tags-links a:focus, 
            .comments-link a:focus, 
            .posted-on a:hover, 
            .posted-on a:focus,
            #secondary a:hover, 
            #secondary a:focus, 
            #secondary .textwidget a, 
            #left-sidebar a:hover, 
            #left-sidebar a:focus, 
            #left-sidebar .textwidget a,
            .btn,
            .post-navigation a, 
            .posts-navigation a,
            .comment-meta .url, 
            .comment-meta .fn,
            .reply a,
            #respond input[type="submit"],
            #colophon .site-info a,
            #colophon .widget-title, 
            #colophon .widgettitle,
            #colophon a:hover, 
            #colophon a:focus,
            .site-title a:hover, 
            .site-title a:focus,
            .main-navigation a:hover, 
            .main-navigation a:focus, 
            .main-navigation ul.nav-menu > li > a:hover, 
            .main-navigation ul.nav-menu > li > a:focus,
            .main-navigation ul#primary-menu > li.current-menu-item > a,
            .main-navigation ul#primary-menu li.current-menu-item > a:hover, 
            .main-navigation ul#primary-menu li:hover > a, 
            .main-navigation ul#primary-menu li:focus > a,
            .pagination .page-numbers.prev, 
            .pagination .page-numbers.next,
            .pagination .page-numbers, 
            .pagination .page-numbers.dots:hover, 
            .pagination .page-numbers.dots:focus,
            .tags-read-more .cat-links a:hover,
            .tags-read-more .cat-links a:focus {
                color: ' . esc_attr( $color ) . ';
            }

            .widget svg,
            .navigation.posts-navigation svg, 
            .navigation.post-navigation svg,
            .widget_search form.search-form button.search-submit:hover svg, 
            .widget_search form.search-form button.search-submit:focus svg,
            .main-navigation ul#primary-menu li:hover > svg, 
            .main-navigation ul#primary-menu li:focus > svg, 
            .main-navigation li.menu-item-has-children:hover > a > svg, 
            .main-navigation li.menu-item-has-children > a:hover > svg, 
            .main-navigation li.menu-item-has-children > a:focus > svg, 
            .main-navigation ul#primary-menu > li.current-menu-item > a > svg,
            .pagination .prev.page-numbers svg, 
            .pagination .next.page-numbers svg {
                fill: ' . esc_attr( $color ) . ';
            }
            /*--------------------------------------------------------------
            ## Background Color
            --------------------------------------------------------------*/
            .btn,
            #respond input[type="submit"] {
                background-color: #f9e5e6;
            }
            .btn:hover, 
            .btn:focus,
            #respond input[type="submit"]:hover, 
            #respond input[type="submit"]:focus,
            .backtotop,
            #page-site-header,
            .pagination .page-numbers.current, 
            .pagination .page-numbers:hover, 
            .pagination .page-numbers:focus,
            span.dropcap {
                background-color: ' . esc_attr( $color ) . ';
            }
            /*--------------------------------------------------------------
            ## Border Color
            --------------------------------------------------------------*/
            #left-sidebar .widget_skills ul li a:hover, 
            #left-sidebar .widget_skills ul li a:focus, 
            #secondary .widget_skills ul li a:hover, 
            #secondary .widget_skills ul li a:focus, 
            .tagcloud a:hover, 
            .tagcloud a:focus {
                border-color: ' . esc_attr( $color ) . ';
            }

            @media screen and (min-width: 1024px) {
                .main-navigation ul ul {
                    border-top-color: ' . esc_attr( $color ) . ';
                }
                .main-navigation ul.nav-menu > li.menu-item-has-children:hover > a:after {
                    border-bottom-color: ' . esc_attr( $color ) . ';
                }
                .main-navigation ul.sub-menu li:hover > a, 
                .main-navigation ul.sub-menu li:focus > a {
                    background-color: ' . esc_attr( $color ) . ';
                }
            }
            ';
    wp_add_inline_style( 'blogbook-style', $custom_css );
}
add_action( 'wp_enqueue_scripts', 'blogbook_custom_color_scheme' );

function blogbook_background_color() {
    $bg_color = get_background_color();
    $custom_css = '
        body {
            background-color: #' . esc_attr( $bg_color ) . '
        }';
    wp_add_inline_style( 'blogbook-style', $custom_css );
}
add_action( 'wp_enqueue_scripts', 'blogbook_background_color' );

// Add comment svg before comment.
add_filter( 'comments_number', 'blogbook_add_comment_svg' );
function blogbook_add_comment_svg( $output ) {
    return blogbook_get_svg( array( 'icon' => 'comment' ) ) . $output;
}

/**
 * Hide the gravatar if id doesn't exists
 */
function blogbook_filter_avatar( $avatar, $id_or_email, $size, $default, $alt, $args ) 
{
    $headers = get_headers( $args['url'] );
    if( ! preg_match( "|200|", $headers[0] ) ) {
        return;
    }

    return $avatar; 
}
add_filter( 'get_avatar','blogbook_filter_avatar', 10, 6 );